@@ -230,7 +230,7 @@ class SocketService(MultiProcService):
         self.init_sockets()
         self.init_socket_server(io_loop=io_loop)
 
-        self.socket_server.start(num_processes=self.config["num_processes"])
+        self.socket_server.start(num_processes=1)
         self.socket_server.add_sockets(self.sockets)
 
     def stop(self):
